@@ -12,18 +12,20 @@ except ImportError:
 
 def parse_xml(response):
     if response.code == 599 or response.buffer is None:
-        raise HTTPError(httplib.SERVICE_UNAVAILABLE, 'Response timeout or no body buffer')
+        raise HTTPError(
+            httplib.SERVICE_UNAVAILABLE, "Response timeout or no body buffer"
+        )
     try:
         return parse(response.buffer)
     except ParseError:
-        raise HTTPError(httplib.SERVICE_UNAVAILABLE, 'Unable to parse xml')
+        raise HTTPError(httplib.SERVICE_UNAVAILABLE, "Unable to parse xml")
 
 
 def parse_json(response):
     if response.code == 599 or response.body is None:
-        raise HTTPError(httplib.SERVICE_UNAVAILABLE, 'Response timeout or no body')
+        raise HTTPError(httplib.SERVICE_UNAVAILABLE, "Response timeout or no body")
     try:
         result = json_decode(response.body)
     except ValueError:
-        raise HTTPError(httplib.SERVICE_UNAVAILABLE, 'Unable to parse json')
+        raise HTTPError(httplib.SERVICE_UNAVAILABLE, "Unable to parse json")
     return result
